# Copyright 1999-2005 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $

inherit eutils flag-o-matic kde linux-info

MY_PNV=${P/_beta2/-beta2}
S=${WORKDIR}/${MY_PNV}

DESCRIPTION="The open source answer to WhereIsIt and Google Desktop Search"
HOMEPAGE="http://kat.sourceforge.net/"
SRC_URI="mirror://sourceforge/${PN}/${MY_PNV}.tar.bz2"

LICENSE="GPL-2"
SLOT="0"
KEYWORDS="~x86 ~amd64 ~alpha ~ppc ~sparc"
IUSE="ext-doc ext-dvi ext-gnumeric ext-html ext-koffice ext-kpresenter 
 ext-kspread ext-kword ext-lyx ext-man ext-openoffice ext-pdf ext-ppt 
 ext-ps ext-rtf ext-tex ext-xls xattr"

RDEPEND=">=dev-db/sqlite-3.2.1
	( || ( ( kde-base/kcontrol kde-base/kicker ) >=kde-base/kdebase-3.3 ) ) 
	ext-doc?	( app-text/antiword )
	ext-dvi?	( dev-tex/dvi2tty )
	ext-gnumeric?	( app-office/gnumeric )
	ext-html?	( app-text/html2text )
	ext-koffice?	( app-text/koffice )
	ext-kpresenter?	( app-office/kpresenter )
	ext-kspread?	( app-office/kspread )
	ext-kword?	( app-office/kword )
	ext-lyx?	( app-text/lyx2html )
	ext-man?	( app-text/man2html )
	ext-openoffice?	( virtual/ooo )
	ext-pdf?	( app-text/xpdf )
	ext-ppt?	( app-text/xlhtml )
	ext-ps?		( app-text/pstotext )
	ext-rtf?	( app-text/unrtf )
	ext-tex?	( dev-tex/untex )
	ext-xls?	( app-text/xlhtml )
	xattr?	( sys-apps/attr )"

# mail-plugin is for now disabled.
# ext-eml?	( net-mail/mhonarc )

DEPEND="${RDEPEND}
	>=dev-util/pkgconfig-0.9.0
	!kde-misc/kat"

need-kde 3.3

src_compile() {
	# Filter fvisibility for now due to compile errors
	filter-flags -fvisibility-inlines-hidden -fvisibility=hidden 

	# Kat wants autoconf and automake set to newer versions.
	export WANT_AUTOCONF=2.5
	export WANT_AUTOMAKE=1.6

        # Unset Unsermake as it does not compile with unsermake enabled.
	export UNSERMAKE=no

	PREFIX="`kde-config --prefix`"
	kde_src_compile
}

pkg_postinst() {
	if ( ! linux_chkconfig_present INOTIFY) && [[ -f /proc/sys/fs/inotify ]] ; then
		eerror "Your kernel does not seem to have inotify support enabled."
		eerror "In order to enable support for Kat's autoupdate deamon,"
		eerror "you need kernel 2.6.13 which includes the minimum version"
		eerror "of Inotify (v0.24) supported by Kat."
		eerror "Enable Inotify file change notification support (INOTIFY)"
		eerror "within the kernel under Device Drivers / Character Devices."
		eerror "For more information regarding the use of Inotify and Kat:"
		eerror "http://rcappuccio.altervista.org/wiki/index.php/Getting_started"
		ebeep 10
	fi

	if [ IUSE=xattr ] ; then
		einfo "You selected support for Extented attributes within Kat."
		einfo "You will need to set extended attributes on the file"
		einfo "systems that the autoupdate deamon of Kat is indexing."
		einfo "(Has to be supported by the kernel e.g. EXT2_FS_XATTR,"
		einfo "EXT3_FS_XATTR or REISERFS_FS_XATTR)"
		einfo ""
		einfo "To set extended attributes, you add 'user_xattr' to the"
		einfo "relevant file systems in your /etc/fstab file. For example:"
		einfo "/dev/hda3   /home  ext3	defaults,user_xattr	1 2"
		ebeep 10
	fi
}
